@@ -6,9 +6,10 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
+use lib 'lib';
 BEGIN { $| = 1; print "1..4\n"; }
 END {print "not ok 1\n" unless $loaded;}
-require "./Multidim.pm";
+use Tie::Multidim;
 $loaded = 1;
 print "ok 1\n";
 
